Function documentation
=============================================

.. autofunction:: fwdpy11.infinite_sites
    
    :param rng: Random number generator
    :type rng: :class:`fwdpy11.GSLrng`
    :param pop: A population
    :type pop: :class:`fwdpy11.Population`
    :param mu: The mutation rate, per haploid genome per generation
    :type mu: float

    :return: Number of mutations added
    :rtype: int

.. autofunction:: fwdpy11.simplify

.. autofunction:: fwdpy11.simplify_tables

.. autofunction:: fwdpy11.evolvets

.. autofunction:: fwdpy11.exponential_growth_rate

.. autofunction:: fwdpy11.migration_matrix_single_extant_deme
